@@ -19,6 +19,8 @@ from gi.repository import Gdk as gdk
 from gi.repository import GLib
 from gi.repository import Pango
 
+from pkg_resources import parse_version
+
 import re
 import sys
 import os
@@ -70,7 +72,10 @@ class IterableIPShell:
     '''
     io = IPython.utils.io
     if input_func:
-      IPython.terminal.interactiveshell.raw_input_original = input_func
+      if parse_version(IPython.release.version) >= parse_version("1.2.1"):
+        IPython.terminal.interactiveshell.raw_input_original = input_func
+      else:
+        IPython.frontend.terminal.interactiveshell.raw_input_original = input_func
     if cin:
       io.stdin = io.IOStream(cin)
     if cout:
@@ -86,7 +91,10 @@ class IterableIPShell:
     os.environ['TERM'] = 'dumb'
     excepthook = sys.excepthook 
 
-    from IPython.config.loader import Config
+    if parse_version(IPython.release.version) >= parse_version('4.0.0'):
+        from traitlets.config.loader import Config
+    else:
+        from IPython.config.loader import Config
     cfg = Config()
     cfg.InteractiveShell.colors = "Linux"
 
@@ -98,8 +106,12 @@ class IterableIPShell:
 
     # InteractiveShell inherits from SingletonConfigurable, so use instance()
     #
-    self.IP = IPython.terminal.embed.InteractiveShellEmbed.instance(\
-            config=cfg, user_ns=user_ns)
+    if parse_version(IPython.release.version) >= parse_version("1.2.1"):
+      self.IP = IPython.terminal.embed.InteractiveShellEmbed.instance(\
+              config=cfg, user_ns=user_ns)
+    else:
+      self.IP = IPython.frontend.terminal.embed.InteractiveShellEmbed.instance(\
+              config=cfg, user_ns=user_ns)
 
     sys.stdout, sys.stderr = old_stdout, old_stderr
 
@@ -116,7 +128,8 @@ class IterableIPShell:
     self.complete_sep =  re.compile('[\s\{\}\[\]\(\)]')
     self.updateNamespace({'exit':lambda:None})
     self.updateNamespace({'quit':lambda:None})
-    self.IP.readline_startup_hook(self.IP.pre_readline)
+    if parse_version(IPython.release.version) < parse_version("5.0.0"):
+      self.IP.readline_startup_hook(self.IP.pre_readline)
     # Workaround for updating namespace with sys.modules
     #
     self.__update_namespace()
@@ -169,7 +182,10 @@ class IterableIPShell:
           self.IP.autoedit_syntax):
           self.IP.edit_syntax_error()
       if not self.iter_more:
-          source_raw = self.IP.input_splitter.raw_reset()
+          if parse_version(IPython.release.version) >= parse_version("2.0.0-dev"):
+            source_raw = self.IP.input_splitter.raw_reset()
+          else:
+            source_raw = self.IP.input_splitter.source_raw_reset()[1]
           self.IP.run_cell(source_raw, store_history=True)
           self.IP.rl_do_indent = False
       else:
@@ -196,13 +212,16 @@ class IterableIPShell:
     # Backwards compatibility with ipyton-0.11
     #
     ver = IPython.__version__
-    if '0.11' in ver:
+    if ver[0:4] == '0.11':
         prompt = self.IP.hooks.generate_prompt(is_continuation)
-    else:
+    elif parse_version(IPython.release.version) < parse_version("5.0.0"):
         if is_continuation:
             prompt = self.IP.prompt_manager.render('in2')
         else:
             prompt = self.IP.prompt_manager.render('in')
+    else:
+        # TODO: update to IPython 5.x and later
+        prompt = "In [%d]: " % self.IP.execution_count
 
     return prompt
 
